@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,7 +35,7 @@ class KPIMTEXTEDIT_EXPORT RichTextComposer : public KPIMTextEdit::RichTextEditor
     Q_OBJECT
 public:
     explicit RichTextComposer(QWidget *parent = nullptr);
-    ~RichTextComposer();
+    ~RichTextComposer() override;
 
     enum Mode {
         Plain,    ///< Plain text mode
