@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -21,14 +21,13 @@
 #ifndef KPIMTEXTEDIT_INSERTTABLEDIALOG_H
 #define KPIMTEXTEDIT_INSERTTABLEDIALOG_H
 
-#include "kpimtextedit_export.h"
 
 #include <QDialog>
 
 #include <QTextLength>
 
 namespace KPIMTextEdit {
-class KPIMTEXTEDIT_EXPORT InsertTableDialog : public QDialog
+class InsertTableDialog : public QDialog
 {
     Q_OBJECT
 public:
