@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -49,14 +49,18 @@ public:
         q->connect(mButtonBox, &QDialogButtonBox::accepted, q, &QDialog::accept);
         q->connect(mButtonBox, &QDialogButtonBox::rejected, q, &QDialog::reject);
 
-        q->connect(okButton, &QPushButton::clicked, q, [this]() { _k_slotInsertChar(); });
+        q->connect(okButton, &QPushButton::clicked, q, [this]() {
+                _k_slotInsertChar();
+            });
     }
 
     void addSelectButton()
     {
         mSelectButton = new QPushButton(i18n("Select"));
         mButtonBox->addButton(mSelectButton, QDialogButtonBox::ActionRole);
-        q->connect(mSelectButton, &QPushButton::clicked, q, [this]() { _k_slotInsertChar(); });
+        q->connect(mSelectButton, &QPushButton::clicked, q, [this]() {
+                _k_slotInsertChar();
+            });
     }
 
     void _k_slotInsertChar();
