@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -38,7 +38,7 @@ class KPIMTEXTEDIT_EXPORT PlainTextEditor : public QPlainTextEdit
     Q_PROPERTY(bool webShortcutSupport READ webShortcutSupport WRITE setWebShortcutSupport)
 public:
     explicit PlainTextEditor(QWidget *parent = nullptr);
-    ~PlainTextEditor();
+    ~PlainTextEditor() override;
 
     enum SupportFeature {
         None = 0,
@@ -121,6 +121,8 @@ private:
     void deleteWordBack();
     void deleteWordForward();
     void highlightWord(int length, int pos);
+    void deleteEndOfLine();
+    void moveLineUpDown(bool moveUp);
     class PlainTextEditorPrivate;
     PlainTextEditorPrivate *const d;
 };
