@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,12 +32,13 @@ class KPIMTEXTEDIT_EXPORT RichTextEditFindBar : public TextEditFindBarBase
     Q_OBJECT
 public:
     explicit RichTextEditFindBar(QTextEdit *view, QWidget *parent = nullptr);
-    ~RichTextEditFindBar();
+    ~RichTextEditFindBar() override;
 
 protected:
     bool viewIsReadOnly() const override;
     bool documentIsEmpty() const override;
     bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) override;
+    bool searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions) override;
     void autoSearchMoveCursor() override;
 
 public Q_SLOTS:
